# ======================
# -*- coding:utf-8 -*-
# @author:Beall
# @time  :2021/11/18 13:54
# @file  :python 接口发布.py
# ======================
import re
import html
from urllib import parse
import requests

GOOGLE_TRANSLATE_URL = 'http://translate.google.cn/m?q=%s&tl=%s&sl=%s'
translate_dict = {
    'afrikaans': 'af',
    'arabic': 'ar',
    'belarusian': 'be',
    'bulgarian': 'bg',
    'catalan': 'ca',
    'czech': 'cs',
    'welsh': 'cy',
    'danish': 'da',
    'german': 'de',
    'greek': 'el',
    'english': 'en',
    'esperanto': 'eo',
    'spanish': 'es',
    'estonian': 'et',
    'persian': 'fa',
    'finnish': 'fi',
    'french': 'fr',
    'irish': 'ga',
    'galician': 'gl',
    'hindi': 'hi',
    'croatian': 'hr',
    'hungarian': 'hu',
    'indonesian': 'id',
    'icelandic': 'is',
    'italian': 'it',
    'hebrew': 'iw',
    'japanese': 'ja',
    'korean': 'ko',
    'latin': 'la',
    'lithuanian': 'lt',
    'latvian': 'lv',
    'macedonian': 'mk',
    'malay': 'ms',
    'maltese': 'mt',
    'dutch': 'nl',
    'norwegian': 'no',
    'polish': 'pl',
    'portuguese': 'pt',
    'romanian': 'ro',
    'russian': 'ru',
    'slovak': 'sk',
    'slovenian': 'sl',
    'albanian': 'sq',
    'serbian': 'sr',
    'swedish': 'sv',
    'swahili': 'sw',
    'thai': 'th',
    'filipino': 'tl',
    'turkish': 'tr',
    'ukrainian': 'uk',
    'vietnamese': 'vi',
    'yiddish': 'yi',
    'chinese_simplified': 'zh-CN',
    'chinese_traditional': 'zh-TW',
    'auto': 'auto'
}


def translate(lan_From, lan_To, text):
    text = parse.quote(text)
    url = GOOGLE_TRANSLATE_URL % (text, lan_To, lan_From)
    response = requests.get(url)
    data = response.text
    expr = r'(?s)class="(?:t0|result-container)">(.*?)<'
    result = re.findall(expr, data)
    if (len(result) == 0):
        return ""

    return html.unescape(result[0])


if __name__ == "__main__":
    text = '''面料名称:蕾丝
是否支持贴牌:不支持
是否支持代工:支持
主面料成分:锦纶/尼龙
主面料成分的含量:90（%）
里料成分:棉
里料成分含量:32.8（%）
款式:超薄型
适用人群:青年女性
风格:性感妩媚
是否无缝:否
是否有钢圈:软钢圈
设计特色:蝴蝶结,提花,蕾丝边
罩杯型:3/4罩杯
模杯类型:超薄模杯
肩带类型:固定双肩带
排扣类型:后双排搭扣
误差范围:0.1-0.2cm
适合季节:夏季,冬季,春季,秋季
是否外贸:是
库存类型:整单
生产周期:45天
质量等级:一等品
是否进口:否
功能:聚拢，透气，大胸显小
主要下游平台:wish,速卖通,独立站,LAZADA,其他'''
    print(translate(lan_From="auto", lan_To="en", text=text))



import threading
import queue


class Thread_Api:
    def __init__(self, item_list, func, threadNum=5, queue_order=1):
        """
        :param item_list: 并发对象列表
        :param func: 工作函数对象
        :param threadNum: 并发数，默认 5
        :param queue_order: 0或1，先进先出/后进先出, 默认为1
        """
        self.item_list = item_list
        self.func = func
        self.queue_order = queue_order
        if queue_order:
            self.q = queue.Queue()  # 先进先出
        else:
            self.q = queue.LifoQueue()  # 后进先出
        self.threadNum = threadNum
        self.lock = threading.Lock()

    def worker(self):
        while not self.q.empty():
            item = self.q.get_nowait()  # 获得任务
            # with self.lock:
            self.func(item)

    def main(self):
        threads = []
        for task in self.item_list:
            self.q.put_nowait(task)
        for i in range(self.threadNum):
            thread = threading.Thread(target=self.worker)
            thread.setDaemon(True)  # 设置守护进程
            thread.start()
            threads.append(thread)
        for thread in threads:  # 线程阻塞
            thread.join()


if __name__ == '__main__':
    pass



# ======================
# -*- coding:utf-8 -*-
# @author:Beall
# @time  :2022/3/2 17:57
# @file  :python添加水印.py
# ======================
from PIL import Image
from PIL import ImageDraw
from PIL import ImageFont


def add_text(text, in_img_path, out_img_path):
    try:
        im = Image.open(in_img_path)
        font = ImageFont.truetype('C:/Windows/Fonts/simsun.ttc', 24)
        draw = ImageDraw.Draw(im)
        draw.text((im.size[0] * 0.03, im.size[1] * 0.03), text, fill=(33, 33, 33), font=font)
        im.save(out_img_path)
    except Exception as e:
        print(f'程序错误: {e}')
        pass


def add_logo(water_mark, in_img_path, out_img_path):
    water_mark = Image.open(water_mark)
    image_file = Image.open(in_img_path)
    layer = Image.new('RGBA', image_file.size, (0, 0, 0, 0))
    layer.paste(water_mark, (int(image_file.size[0] * 0.04), int(image_file.size[1] * 0.03)))
    out = Image.composite(layer, image_file, layer)
    out.save(out_img_path)


if __name__ == '__main__':
    pass



# ======================
# -*- coding:utf-8 -*-
# @author:Beall
# @time  :2022/1/14 13:51
# @file  :ftp_upload.py
# ======================
import paramiko
import datetime
import os


def upload(hostname, username, password, port, local_dir, remote_dir):
    img_list = []
    try:
        t = paramiko.Transport((hostname, port))
        t.connect(username=username, password=password)
        sftp = paramiko.SFTPClient.from_transport(t)
        print('upload file start %s ' % datetime.datetime.now())
        for root, dirs, files in os.walk(local_dir):
            # print('[%s][%s][%s]' % (root, dirs, files))
            detail_index = 0
            for filespath in files:
                if 'jpg' in filespath and 'detail' in filespath and detail_index < 7:
                    local_file = os.path.join(root, filespath)
                    # print(11, '[%s][%s][%s][%s]' % (root, filespath, local_file, local_dir))
                    a = local_file.replace(local_dir, '').replace('\\', '/').lstrip('/')
                    # print('01', a, '[%s]' % remote_dir)
                    remote_file = os.path.join(remote_dir, a)
                    # print(22, remote_file)
                    img_list.append(remote_file)
                    try:
                        sftp.put(local_file, remote_file)
                        sftp.chmod(remote_file, 0o705)
                    except Exception as e:
                        sftp.mkdir(os.path.split(remote_file)[0])
                        sftp.put(local_file, remote_file)
                        sftp.chmod(os.path.split(remote_file)[0], 0o705)
                        sftp.chmod(remote_file, 0o705)
                        # print("66 upload %s to remote %s" % (local_file, remote_file))
                    detail_index += 1
                elif 'jpg' in filespath and 'detail' not in filespath:
                    local_file = os.path.join(root, filespath)
                    # print(11, '[%s][%s][%s][%s]' % (root, filespath, local_file, local_dir))
                    a = local_file.replace(local_dir, '').replace('\\', '/').lstrip('/')
                    # print('01', a, '[%s]' % remote_dir)
                    remote_file = os.path.join(remote_dir, a)
                    # print(22, remote_file)
                    img_list.append(remote_file)
                    try:
                        sftp.put(local_file, remote_file)
                        sftp.chmod(remote_file, 0o705)
                    except Exception as e:
                        sftp.mkdir(os.path.split(remote_file)[0])
                        sftp.chmod(os.path.split(remote_file)[0], 0o705)
                        sftp.put(local_file, remote_file)
                        sftp.chmod(remote_file, 0o705)
        #                 print("66 upload %s to remote %s" % (local_file, remote_file))
        print('upload file success %s ' % datetime.datetime.now())
        t.close()
    except Exception as e:
        print(e)
    img_list = [i.replace('/www/wwwroot/', 'https://') for i in img_list]
    return img_list


if __name__ == '__main__':
    pass


# ======================
# -*- coding:utf-8 -*-
# @author:Beall
# @time  :2022/3/23 14:43
# @file  :exchange_rate.py
# ======================
import requests
from bs4 import BeautifulSoup


def exchange_rate(form_currency, to_currency="USD", num=1):
    """
    汇率换算
    :param form_currency: 需要转化的币种
    :param to_currency: 待转化的币种, 默认USD(美元)
    :param num: 需要转化的钱, 默认为1
    :return: 实时汇率
    """
    print(f'正在查询{form_currency} => {to_currency}汇率...')
    for i in range(3):
        try:
            header = {
                'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) '
                              'Chrome/89.0.4389.90 Safari/537.36',
                'Accept-Language': 'zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7',
                'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/'
                          '*;q=0.8,application/signed-exchange;v=b3;q=0.9',
                'Accept-Encoding': 'gzip, deflate, br',
                'Host': 'qq.ip138.com'}
            url = f"https://qq.ip138.com/hl.asp?from={form_currency}&to={to_currency}&q={num}"
            web = requests.get(url, headers=header)
            if web.status_code == 200:
                soup = BeautifulSoup(web.text, 'html.parser')
                result = float([i.get_text() for i in soup.find_all("td")][-1])
                print(f'查询成功, {num} {form_currency} = {result} {to_currency}')
                return result
                break
            else:
                raise Exception
        except Exception as e:
            print(f'出错:{e}, url: {url}, 重试次数:{i + 1}')
        if i == 2:
            print('三次重试均失败！')


if __name__ == '__main__':
    exchange_rate('CNY')



# ======================
# -*- coding:utf-8 -*-
# @author:Beall
# @time  :2022/3/31 9:48
# @file  :setup.py.py
# ======================
from setuptools import setup

setup(
    name='ShareClass',  # 包名字
    version='1.0.2',  # 包版本
    description='A code base to python common function management!',  # 简单描述
    long_description='A code base to python common function management!',  # 简单描述
    author='beall',  # 作者
    author_email='beallhuang@163.com',  # 作者邮箱
    url='https://www.easylfe.com',  # 包的主页
    packages=['ShareClass'],  # 包
    platforms=['windows'],
    install_requires=['requests',
                      'Pillow'
                      'paramiko',
                      'bs4'],
    python_requires='>=3.6'
)



from PIL import Image
import os


def produceImage(file_in, file_out):
    image = Image.open(file_in)
    if min(image.size) < 500:
        if image.size[0] >= image.size[1]:
            resized_image = image.resize((int(500*image.size[0]/image.size[1]), 500), Image.ANTIALIAS)
        else:
            resized_image = image.resize((500, int(500 * image.size[1] / image.size[0])), Image.ANTIALIAS)
        resized_image.save(file_out)


if __name__ == '__main__':
    pass


# -*- coding: utf-8 -*-
# @Time    : 2021/7/3 17:44
# @Author  : Beall
# @File    : Update_chromedriver.py
# @Software: win10 python3.7
import requests
import os
import time
import zipfile


def unzip_file(zip_src, dst_dir):
    r = zipfile.is_zipfile(zip_src)
    if r:
        fz = zipfile.ZipFile(zip_src, 'r')
        for file in fz.namelist():
            fz.extract(file, dst_dir)
    else:
        print('This is not zip')


def main():
    time_version_dict = {}  # 用来存放版本与时间对应关系
    time_list = []  # 用来存放时间列表

    web = requests.get('https://registry.npmmirror.com/-/binary/chromedriver/')
    for i in web.json():
        if i['type'] == 'dir' and i['name'] != 'icons/':
            time_list.append(i['modified'])
            time_version_dict[i['modified']] = i['name']

    latest_version = time_version_dict[max(time_list)]  # 用最大（新）时间去字典中获取最新的版本号
    download_url = 'http://npm.taobao.org/mirrors/chromedriver/' + latest_version + 'chromedriver_win32.zip'  # 拼接下载链接
    file = requests.get(download_url)
    with open("chromedriver.zip", 'wb') as zip_file:  # 保存文件到脚本所在目录
        zip_file.write(file.content)
    while True:
        if os.path.exists("chromedriver.zip"):
            unzip_file("chromedriver.zip", os.path.abspath(os.getcwd()))
            break
        else:
            time.sleep(1)
    print(f'{latest_version} 号版本chromedriver，最新修改时间为{max(time_list)} 已下载完成！\n文件已解压至: '
          f'{os.path.abspath(os.getcwd())}/chromedriver.exe')
    os.remove("chromedriver.zip")


if __name__ == '__main__':
    main()
